FROM ubuntu:20.04
LABEL description="manta parachain node"

ARG PARA_BINARY_REF

ARG PARA_GENESIS_REF=manta
ARG PARA_BINARY_URL=https://github.com/Manta-Network/Manta/releases/download/$PARA_BINARY_REF/manta
ARG PARA_BINARY_PATH=/usr/local/bin/parachain

ARG PARA_GENESIS_URL=https://raw.githubusercontent.com/Manta-Network/Manta/$PARA_GENESIS_REF/genesis/manta-genesis.json
ARG PARA_GENESIS_PATH=/usr/share/manta.json

ARG RELAY_GENESIS_URL=https://raw.githubusercontent.com/paritytech/polkadot/master/node/service/chain-specs/polkadot.json
ARG RELAY_GENESIS_PATH=/usr/share/polkadot.json

ARG SUBSTRATE_BASE_PATH=/var/lib/substrate
ARG SUBSTRATE_PORT=30333
ARG SUBSTRATE_RPC_PORT=9933
ARG SUBSTRATE_RPC_CORS=all
ARG SUBSTRATE_RPC_METHODS=safe
ARG SUBSTRATE_WS_PORT=9944
ARG SUBSTRATE_WS_MAX_CONNECTIONS=100
ARG SUBSTRATE_BOOTNODE_0=/dns/alfredi.manta.systems/tcp/30333/p2p/12D3KooWKMw84HHuEbjHep6FVqUM2sss6TCzqehfXKw3PGoB4HoG
ARG SUBSTRATE_BOOTNODE_1=/dns/birostris.manta.systems/tcp/30333/p2p/12D3KooWP5ASruuz1BEnD5M1QMSS7GiiFTnXMNoDUDn7o9GmcRyZ
ARG SUBSTRATE_BOOTNODE_2=/dns/eregoodootenkey.manta.systems/tcp/30333/p2p/12D3KooWCKgXKVYbpxkmouHBrCyaPGr7NJSHVAgncUPVzH9fTB5e
ARG SUBSTRATE_BOOTNODE_3=/dns/hypostoma.manta.systems/tcp/30333/p2p/12D3KooWHF462NFNuhPAK3cmqZ6c9jD85GnknsFT43n8TFdWcxJY
ARG SUBSTRATE_BOOTNODE_4=/dns/japanica.manta.systems/tcp/30333/p2p/12D3KooWQvvB62n2dEWEYxUCcqzU6dxzVgi8ACPA6X7VeWzxAFMF

# install deps
RUN apt-get update
RUN apt-get upgrade -y
ARG DEBIAN_FRONTEND=noninteractive
RUN apt-get install -yq openssl
RUN apt-get install -yq libssl-dev

RUN mkdir -p /usr/local/bin
RUN mkdir -p /usr/share
RUN mkdir -p $SUBSTRATE_BASE_PATH

ADD $PARA_BINARY_URL $PARA_BINARY_PATH
RUN chmod +x $PARA_BINARY_PATH
RUN ldd $PARA_BINARY_PATH
RUN $PARA_BINARY_PATH --version

ADD $PARA_GENESIS_URL $PARA_GENESIS_PATH
ADD $RELAY_GENESIS_URL $RELAY_GENESIS_PATH

EXPOSE $SUBSTRATE_PORT
EXPOSE $SUBSTRATE_RPC_PORT
EXPOSE $SUBSTRATE_WS_PORT

ENV PARA_BINARY_PATH=$PARA_BINARY_PATH
ENV PARA_GENESIS_PATH=$PARA_GENESIS_PATH
ENV SUBSTRATE_BASE_PATH=$SUBSTRATE_BASE_PATH
ENV SUBSTRATE_PORT=$SUBSTRATE_PORT
ENV SUBSTRATE_RPC_PORT=$SUBSTRATE_RPC_PORT
ENV SUBSTRATE_WS_PORT=$SUBSTRATE_WS_PORT
ENV SUBSTRATE_RPC_CORS=$SUBSTRATE_RPC_CORS
ENV SUBSTRATE_RPC_METHODS=$SUBSTRATE_RPC_METHODS
ENV SUBSTRATE_WS_MAX_CONNECTIONS=$SUBSTRATE_WS_MAX_CONNECTIONS
ENV SUBSTRATE_BOOTNODE_0=$SUBSTRATE_BOOTNODE_0
ENV SUBSTRATE_BOOTNODE_1=$SUBSTRATE_BOOTNODE_1
ENV SUBSTRATE_BOOTNODE_2=$SUBSTRATE_BOOTNODE_2
ENV SUBSTRATE_BOOTNODE_3=$SUBSTRATE_BOOTNODE_3
ENV SUBSTRATE_BOOTNODE_4=$SUBSTRATE_BOOTNODE_4
ENV RELAY_GENESIS_PATH=$RELAY_GENESIS_PATH

ENTRYPOINT $PARA_BINARY_PATH \
  --chain $PARA_GENESIS_PATH \
  --base-path $SUBSTRATE_BASE_PATH \
  --port $SUBSTRATE_PORT \
  --ws-port $SUBSTRATE_WS_PORT \
  --ws-external \
  --rpc-port $SUBSTRATE_RPC_PORT \
  --rpc-external \
  --rpc-cors $SUBSTRATE_RPC_CORS \
  --rpc-methods $SUBSTRATE_RPC_METHODS \
  --ws-max-connections $SUBSTRATE_WS_MAX_CONNECTIONS \
  --bootnodes \
    $SUBSTRATE_BOOTNODE_0 \
    $SUBSTRATE_BOOTNODE_1 \
    $SUBSTRATE_BOOTNODE_2 \
    $SUBSTRATE_BOOTNODE_3 \
    $SUBSTRATE_BOOTNODE_4 \
  -- \
  --chain $RELAY_GENESIS_PATH
